@@ -210,13 +210,15 @@ typedef struct
   GtkWidget *child;
   gboolean prefer_wide_layout;
 
-  GList *responses;
+  GPtrArray *responses;
   GHashTable *id_to_response;
   GQuark default_response;
   GQuark close_response;
 
   gboolean block_close_response;
   gboolean is_short;
+
+  GBinding *child_visible_binding;
 } AdwAlertDialogPrivate;
 
 static void adw_alert_dialog_buildable_init (GtkBuildableIface *iface);
@@ -384,7 +386,7 @@ adw_alert_dialog_grab_focus (GtkWidget *widget)
 
   if (!focus) {
     GtkWidget *default_widget;
-    GList *l;
+    guint i;
 
     if (adw_widget_grab_focus_child (priv->scrolled_window)) {
       focus = adw_dialog_get_focus (ADW_DIALOG (self));
@@ -399,8 +401,8 @@ adw_alert_dialog_grab_focus (GtkWidget *widget)
     if (default_widget)
       return gtk_widget_grab_focus (default_widget);
 
-    for (l = g_list_last (priv->responses); l; l = l->prev) {
-      ResponseInfo *response = l->data;
+    for (i = 0; i < priv->responses->len; i++) {
+      ResponseInfo *response = g_ptr_array_index (priv->responses, i);
 
       if (!response->enabled)
         continue;
@@ -526,14 +528,14 @@ measure_responses_do (AdwAlertDialog *self,
                       int            *natural)
 {
   AdwAlertDialogPrivate *priv = adw_alert_dialog_get_instance_private (self);
-  GList *l;
+  guint i;
   int min = 0, nat = 0;
   int button_min = 0, button_nat = 0;
   int n_buttons = 0;
   gboolean horiz = (orientation == GTK_ORIENTATION_HORIZONTAL);
 
-  for (l = priv->responses; l; l = l->next) {
-    ResponseInfo *response = l->data;
+  for (i = 0; i < priv->responses->len; i++) {
+    ResponseInfo *response = g_ptr_array_index (priv->responses, i);
     int child_min, child_nat;
 
     gtk_widget_measure (response->button, orientation, -1,
@@ -551,7 +553,7 @@ measure_responses_do (AdwAlertDialog *self,
       nat += child_nat;
     }
 
-    if (horiz != compact && l->next) {
+    if (horiz != compact && i + 1 < priv->responses->len) {
       min += BUTTON_SPACING;
       nat += BUTTON_SPACING;
     }
@@ -628,10 +630,10 @@ allocate_responses (GtkWidget *widget,
 
   if (compact) {
     int pos = height;
-    GList *l;
+    guint i;
 
-    for (l = priv->responses; l; l = l->next) {
-      ResponseInfo *response = l->data;
+    for (i = 0; i < priv->responses->len; i++) {
+      ResponseInfo *response = g_ptr_array_index (priv->responses, i);
       int child_height;
 
       gtk_widget_measure (response->button, GTK_ORIENTATION_VERTICAL, -1,
@@ -647,13 +649,13 @@ allocate_responses (GtkWidget *widget,
   } else {
     gboolean is_rtl = gtk_widget_get_direction (widget) == GTK_TEXT_DIR_RTL;
     int pos = is_rtl ? width : 0;
-    int n_buttons = g_list_length (priv->responses);
+    int n_buttons = priv->responses->len;
     int total_width = width - BUTTON_SPACING * MAX (0, (n_buttons - 1));
     int button_width = (int) ceil ((double) total_width / n_buttons);
-    GList *l;
+    guint i;
 
-    for (l = priv->responses; l; l = l->next) {
-      ResponseInfo *response = l->data;
+    for (i = 0; i < priv->responses->len; i++) {
+      ResponseInfo *response = g_ptr_array_index (priv->responses, i);
 
       button_width = MIN (button_width, total_width);
 
@@ -861,11 +863,7 @@ adw_alert_dialog_dispose (GObject *object)
 
   priv->child = NULL;
 
-  if (priv->responses) {
-    g_list_free_full (priv->responses, (GDestroyNotify) response_info_free);
-    priv->responses = NULL;
-  }
-
+  g_clear_pointer (&priv->responses, g_ptr_array_unref);
   g_clear_pointer (&priv->id_to_response, g_hash_table_unref);
 
   G_OBJECT_CLASS (adw_alert_dialog_parent_class)->dispose (object);
@@ -986,10 +984,13 @@ adw_alert_dialog_class_init (AdwAlertDialogClass *klass)
    *
    * The response ID of the default response.
    *
-   * If set, pressing <kbd>Enter</kbd> will activate the corresponding button.
+   * The button corresponding to this response will be set as the default widget
+   * of the dialog.
    *
-   * If set to `NULL` or a non-existent response ID, pressing <kbd>Enter</kbd>
-   * will do nothing.
+   * If not set, the default widget will not be set, and the last added response
+   * will be focused by default.
+   *
+   * See [property@Dialog:default-widget].
    *
    * Since: 1.5
    */
@@ -1077,6 +1078,7 @@ adw_alert_dialog_init (AdwAlertDialog *self)
 
   priv->heading = g_strdup ("");
   priv->body = g_strdup ("");
+  priv->responses = g_ptr_array_new_full (0, (GDestroyNotify) response_info_free);
   priv->id_to_response = g_hash_table_new_full (g_str_hash, g_str_equal, g_free, NULL);
 
   gtk_widget_init_template (GTK_WIDGET (self));
@@ -1334,10 +1336,12 @@ adw_alert_dialog_buildable_add_child (GtkBuildable *buildable,
 {
   AdwAlertDialog *self = ADW_ALERT_DIALOG (buildable);
 
-  if (GTK_IS_WIDGET (child))
+  if (GTK_IS_WIDGET (child)) {
+    gtk_buildable_child_deprecation_warning (buildable, builder, NULL, "extra-child");
     adw_alert_dialog_set_extra_child (self, GTK_WIDGET (child));
-  else
+  } else {
     parent_buildable_iface->add_child (buildable, builder, child, type);
+  }
 }
 
 static void
@@ -1855,9 +1859,19 @@ adw_alert_dialog_set_extra_child (AdwAlertDialog *self,
   if (child)
     g_return_if_fail (gtk_widget_get_parent (child) == NULL);
 
+  g_clear_pointer (&priv->child_visible_binding, g_binding_unbind);
+
   priv->child = child;
   adw_bin_set_child (ADW_BIN (priv->child_bin), child);
-  gtk_widget_set_visible (priv->child_bin, child != NULL);
+
+  if (child) {
+    priv->child_visible_binding =
+      g_object_bind_property (child, "visible",
+                              priv->child_bin, "visible",
+                              G_BINDING_SYNC_CREATE);
+  } else {
+    gtk_widget_set_visible (priv->child_bin, FALSE);
+  }
 
   g_object_notify_by_pspec (G_OBJECT (self), props[PROP_EXTRA_CHILD]);
 }
@@ -1974,7 +1988,7 @@ adw_alert_dialog_add_response (AdwAlertDialog *self,
   info->button = create_response_button (self, info);
   gtk_widget_set_parent (info->button, priv->response_area);
 
-  priv->responses = g_list_append (priv->responses, info);
+  g_ptr_array_add (priv->responses, info);
   g_hash_table_insert (priv->id_to_response, g_strdup (id), info);
 
   if (priv->default_response == info->id)
@@ -2070,10 +2084,8 @@ adw_alert_dialog_remove_response (AdwAlertDialog *self,
 
   gtk_widget_unparent (info->button);
 
-  priv->responses = g_list_remove (priv->responses, info);
+  g_ptr_array_remove (priv->responses, info);
   g_hash_table_remove (priv->id_to_response, id);
-
-  response_info_free (info);
 }
 
 /**
@@ -2177,14 +2189,15 @@ adw_alert_dialog_get_response_appearance (AdwAlertDialog *self,
  *   <img src="alert-dialog-appearance.png" alt="alert-dialog-appearance">
  * </picture>
  *
- * Use `ADW_RESPONSE_SUGGESTED` to mark important responses such as the
- * affirmative action, like the Save button in the example.
+ * Use [enum@Adw.ResponseAppearance.suggested] to mark important responses such
+ * as the affirmative action, like the Save button in the example.
  *
- * Use `ADW_RESPONSE_DESTRUCTIVE` to draw attention to the potentially damaging
- * consequences of using @response. This appearance acts as a warning to the
- * user. The Discard button in the example is using this appearance.
+ * Use [enum@Adw.ResponseAppearance.destructive] to draw attention to the
+ * potentially damaging consequences of using @response. This appearance acts as
+ * a warning to the user. The Discard button in the example is using this
+ * appearance.
  *
- * The default appearance is `ADW_RESPONSE_DEFAULT`.
+ * The default appearance is [enum@Adw.ResponseAppearance.default].
  *
  * Negative responses like Cancel or Close should use the default appearance.
  *
@@ -2323,10 +2336,13 @@ adw_alert_dialog_get_default_response (AdwAlertDialog *self)
  *
  * Sets the ID of the default response of @self.
  *
- * If set, pressing <kbd>Enter</kbd> will activate the corresponding button.
+ * The button corresponding to this response will be set as the default widget
+ * of @self.
  *
- * If set to `NULL` or to a non-existent response ID, pressing <kbd>Enter</kbd>
- * will do nothing.
+ * If not set, the default widget will not be set, and the last added response
+ * will be focused by default.
+ *
+ * See [property@Dialog:default-widget].
  *
  * Since: 1.5
  */
@@ -2529,4 +2545,3 @@ adw_alert_dialog_choose_finish (AdwAlertDialog *self,
 
   return g_quark_to_string (id);
 }
-
