@@ -12,6 +12,7 @@
 
 #include "adw-bin.h"
 #include "adw-dialog-private.h"
+#include "adw-gtkbuilder-utils-private.h"
 #include "adw-widget-utils-private.h"
 
 struct _AdwDialogHost
@@ -59,6 +60,15 @@ struct _AdwDialogModel
   AdwDialogHost *host;
 };
 
+enum {
+  MODEL_PROP_0,
+  MODEL_PROP_ITEM_TYPE,
+  MODEL_PROP_N_ITEMS,
+  N_MODEL_PROPS,
+};
+
+static GParamSpec *model_props[N_MODEL_PROPS];
+
 static GType
 adw_dialog_model_get_item_type (GListModel *model)
 {
@@ -120,12 +130,59 @@ adw_dialog_model_dispose (GObject *object)
   G_OBJECT_CLASS (adw_dialog_model_parent_class)->dispose (object);
 }
 
+static void
+adw_dialog_model_get_property (GObject    *object,
+                               guint       prop_id,
+                               GValue     *value,
+                               GParamSpec *pspec)
+{
+  AdwDialogModel *self = ADW_DIALOG_MODEL (object);
+
+  switch (prop_id) {
+  case MODEL_PROP_ITEM_TYPE:
+    g_value_set_gtype (value, ADW_TYPE_DIALOG);
+    break;
+  case MODEL_PROP_N_ITEMS:
+    g_value_set_uint (value, adw_dialog_model_get_n_items (G_LIST_MODEL (self)));
+    break;
+  default:
+    G_OBJECT_WARN_INVALID_PROPERTY_ID (object, prop_id, pspec);
+  }
+}
+
 static void
 adw_dialog_model_class_init (AdwDialogModelClass *klass)
 {
   GObjectClass *object_class = G_OBJECT_CLASS (klass);
 
   object_class->dispose = adw_dialog_model_dispose;
+  object_class->get_property = adw_dialog_model_get_property;
+
+  /**
+   * AdwDialogModel:item-type:
+   *
+   * The type of the items. See [method@Gio.ListModel.get_item_type].
+   *
+   * Since: 1.9
+   */
+  model_props[MODEL_PROP_ITEM_TYPE] =
+    g_param_spec_gtype ("item-type", NULL, NULL,
+                        ADW_TYPE_DIALOG,
+                        G_PARAM_READABLE | G_PARAM_STATIC_STRINGS);
+
+  /**
+   * AdwDialogModel:n-items:
+   *
+   * The number of items. See [method@Gio.ListModel.get_n_items].
+   *
+   * Since: 1.9
+   */
+  model_props[MODEL_PROP_N_ITEMS] =
+    g_param_spec_uint ("n-items", NULL, NULL,
+                       0, G_MAXUINT, 0,
+                       G_PARAM_READABLE | G_PARAM_STATIC_STRINGS);
+
+  g_object_class_install_properties (object_class, N_MODEL_PROPS, model_props);
 }
 
 static GListModel *
@@ -167,8 +224,10 @@ dialog_closing_cb (AdwDialog     *dialog,
 
   adw_dialog_set_closing (dialog, TRUE);
 
-  if (self->dialogs_model)
+  if (self->dialogs_model) {
     g_list_model_items_changed (self->dialogs_model, index, 1, 0);
+    g_object_notify_by_pspec (G_OBJECT (self->dialogs_model), model_props[MODEL_PROP_N_ITEMS]);
+  }
 
   if (self->dialogs->len == 0) {
     gtk_widget_set_can_focus (self->bin, TRUE);
@@ -204,15 +263,6 @@ dialog_remove_cb (AdwDialog     *dialog,
     gtk_widget_unparent (GTK_WIDGET (dialog));
 }
 
-static gboolean
-key_pressed_cb (AdwDialogHost *self)
-{
-  if (self->dialogs->len == 0)
-    return GDK_EVENT_PROPAGATE;
-
-  return GDK_EVENT_STOP;
-}
-
 static void
 adw_dialog_host_root (GtkWidget *widget)
 {
@@ -310,8 +360,10 @@ adw_dialog_host_dispose (GObject *object)
 {
   AdwDialogHost *self = ADW_DIALOG_HOST (object);
 
-  if (self->dialogs_model)
+  if (self->dialogs_model) {
     g_list_model_items_changed (self->dialogs_model, 0, self->dialogs->len, 0);
+    g_object_notify_by_pspec (G_OBJECT (self->dialogs_model), model_props[MODEL_PROP_N_ITEMS]);
+  }
 
   if (self->dialogs) {
     int i;
@@ -427,18 +479,12 @@ adw_dialog_host_class_init (AdwDialogHostClass *klass)
 static void
 adw_dialog_host_init (AdwDialogHost *self)
 {
-  GtkEventController *controller;
-
   self->dialogs = g_ptr_array_new ();
 
   self->dialogs_closed_during_unmap = g_ptr_array_new ();
 
   self->bin = adw_bin_new ();
   gtk_widget_set_parent (self->bin, GTK_WIDGET (self));
-
-  controller = gtk_event_controller_key_new ();
-  g_signal_connect_swapped (controller, "key-pressed", G_CALLBACK (key_pressed_cb), self);
-  gtk_widget_add_controller (GTK_WIDGET (self), controller);
 }
 
 static void
@@ -447,10 +493,12 @@ adw_dialog_host_buildable_add_child (GtkBuildable *buildable,
                                      GObject      *child,
                                      const char   *type)
 {
-  if (GTK_IS_WIDGET (child))
+  if (GTK_IS_WIDGET (child)) {
+    gtk_buildable_child_deprecation_warning (buildable, builder, NULL, "child");
     adw_dialog_host_set_child (ADW_DIALOG_HOST (buildable), GTK_WIDGET (child));
-  else
+  } else {
     parent_buildable_iface->add_child (buildable, builder, child, type);
+  }
 }
 
 static void
@@ -579,8 +627,10 @@ adw_dialog_host_present_dialog (AdwDialogHost *self,
 
   g_ptr_array_add (self->dialogs, dialog);
 
-  if (self->dialogs_model)
+  if (self->dialogs_model) {
     g_list_model_items_changed (self->dialogs_model, self->dialogs->len - 1, 0, 1);
+    g_object_notify_by_pspec (G_OBJECT (self->dialogs_model), model_props[MODEL_PROP_N_ITEMS]);
+  }
 
   if (gtk_window_get_focus_visible (GTK_WINDOW (root)))
     gtk_window_set_focus_visible (GTK_WINDOW (root), TRUE);
