@@ -15,6 +15,7 @@
 #include "adw-dialog-host-private.h"
 #include "adw-floating-sheet-private.h"
 #include "adw-gizmo-private.h"
+#include "adw-gtkbuilder-utils-private.h"
 #include "adw-marshalers.h"
 #include "adw-widget-utils-private.h"
 
@@ -25,8 +26,9 @@
 
 /**
  * AdwDialogPresentationMode:
- * @ADW_DIALOG_AUTO: Switch between `ADW_DIALOG_FLOATING` and
- *   `ADW_DIALOG_BOTTOM_SHEET` depending on available size.
+ * @ADW_DIALOG_AUTO: Switch between [enum@Adw.DialogPresentationMode.floating]
+ *   and [enum@Adw.DialogPresentationMode.bottom-sheet] depending on available
+ *   size.
  * @ADW_DIALOG_FLOATING: Present dialog as a centered floating window.
  * @ADW_DIALOG_BOTTOM_SHEET: Present dialog as a bottom sheet.
  *
@@ -144,14 +146,17 @@ typedef struct
   gpointer user_data;
 
   GtkWidget *window;
+  GtkEventController *window_close_controller;
   gboolean force_closing;
 } AdwDialogPrivate;
 
 static void adw_dialog_buildable_init (GtkBuildableIface *iface);
+static void adw_dialog_shortcut_manager_init (GtkShortcutManagerInterface *iface);
 
 G_DEFINE_TYPE_WITH_CODE (AdwDialog, adw_dialog, GTK_TYPE_WIDGET,
                          G_ADD_PRIVATE (AdwDialog)
-                         G_IMPLEMENT_INTERFACE (GTK_TYPE_BUILDABLE, adw_dialog_buildable_init))
+                         G_IMPLEMENT_INTERFACE (GTK_TYPE_BUILDABLE, adw_dialog_buildable_init)
+                         G_IMPLEMENT_INTERFACE (GTK_TYPE_SHORTCUT_MANAGER, adw_dialog_shortcut_manager_init))
 
 static GtkBuildableIface *parent_buildable_iface;
 
@@ -180,6 +185,12 @@ enum {
 
 static guint signals[SIGNAL_LAST_SIGNAL];
 
+static void
+child_breakpoint_bin_notify_current_breakpoint_cb (AdwDialog *self)
+{
+  g_object_notify_by_pspec (G_OBJECT (self), props[PROP_CURRENT_BREAKPOINT]);
+}
+
 static gboolean
 map_tick_cb (AdwDialog *self)
 {
@@ -501,6 +512,7 @@ update_presentation (AdwDialog *self)
     priv->bottom_sheet = ADW_BOTTOM_SHEET (adw_bottom_sheet_new ());
 
     adw_bottom_sheet_set_min_natural_width (priv->bottom_sheet, 360);
+    adw_bottom_sheet_set_handle_focus (priv->bottom_sheet, FALSE);
 
     if (!priv->first_map)
       adw_bottom_sheet_set_open (priv->bottom_sheet, TRUE);
@@ -603,7 +615,6 @@ present_as_window (AdwDialog *self,
 {
   AdwDialogPrivate *priv = adw_dialog_get_instance_private (self);
   GtkWidget *titlebar;
-  GtkEventController *shortcut_controller;
   GtkShortcut *shortcut;
 
   if (priv->window) {
@@ -622,9 +633,10 @@ present_as_window (AdwDialog *self,
   shortcut = gtk_shortcut_new (gtk_keyval_trigger_new (GDK_KEY_Escape, 0),
                                gtk_callback_action_new ((GtkShortcutFunc) maybe_close_cb, self, NULL));
 
-  shortcut_controller = gtk_shortcut_controller_new ();
-  gtk_shortcut_controller_add_shortcut (GTK_SHORTCUT_CONTROLLER (shortcut_controller), shortcut);
-  gtk_widget_add_controller (priv->window, shortcut_controller);
+  priv->window_close_controller = gtk_shortcut_controller_new ();
+  gtk_shortcut_controller_set_scope (GTK_SHORTCUT_CONTROLLER (priv->window_close_controller), GTK_SHORTCUT_SCOPE_MANAGED);
+  gtk_shortcut_controller_add_shortcut (GTK_SHORTCUT_CONTROLLER (priv->window_close_controller), shortcut);
+  gtk_widget_add_controller (GTK_WIDGET (self), priv->window_close_controller);
 
   if (parent) {
     GtkRoot *root = gtk_widget_get_root (parent);
@@ -655,13 +667,7 @@ present_as_window (AdwDialog *self,
 static gboolean
 activate_focus_cb (AdwDialog *self)
 {
-  AdwDialogPrivate *priv = adw_dialog_get_instance_private (self);
-  GtkRoot *root;
-
-  if (priv->window)
-    return GDK_EVENT_PROPAGATE;
-
-  root = gtk_widget_get_root (GTK_WIDGET (self));
+  GtkRoot *root = gtk_widget_get_root (GTK_WIDGET (self));
 
   if (!GTK_IS_WINDOW (root))
     return GDK_EVENT_PROPAGATE;
@@ -674,13 +680,7 @@ activate_focus_cb (AdwDialog *self)
 static gboolean
 activate_default_cb (AdwDialog *self)
 {
-  AdwDialogPrivate *priv = adw_dialog_get_instance_private (self);
-  GtkRoot *root;
-
-  if (priv->window)
-    return GDK_EVENT_PROPAGATE;
-
-  root = gtk_widget_get_root (GTK_WIDGET (self));
+  GtkRoot *root = gtk_widget_get_root (GTK_WIDGET (self));
 
   if (!GTK_IS_WINDOW (root))
     return GDK_EVENT_PROPAGATE;
@@ -1150,13 +1150,14 @@ adw_dialog_class_init (AdwDialogClass *klass)
    *
    * The dialog's presentation mode.
    *
-   * When set to `ADW_DIALOG_AUTO`, the dialog appears as a bottom sheet when
-   * the following condition is met: `max-width: 450px or max-height: 360px`,
-   * and as a floating window otherwise.
+   * When set to [enum@Adw.DialogPresentationMode.auto], the dialog appears as a
+   * bottom sheet when the following condition is met:
+   * `max-width: 450px or max-height: 360px`, and as a floating window otherwise.
    *
-   * Set it to `ADW_DIALOG_FLOATING` or `ADW_DIALOG_BOTTOM_SHEET` to always
-   * present it a floating window or a bottom sheet respectively, regardless of
-   * available size.
+   * Set it to [enum@Adw.DialogPresentationMode.floating] or
+   * [enum@Adw.DialogPresentationMode.bottom-sheet] to always present it a
+   * floating window or a bottom sheet respectively, regardless of available
+   * size.
    *
    * Presentation mode does nothing for dialogs presented as a window.
    *
@@ -1302,6 +1303,8 @@ adw_dialog_init (AdwDialog *self)
   priv->follows_content_size = FALSE;
   priv->presentation_mode = ADW_DIALOG_AUTO;
 
+  gtk_widget_set_limit_events (GTK_WIDGET (self), TRUE);
+
   priv->child_breakpoint_bin = adw_breakpoint_bin_new ();
   gtk_widget_set_overflow (priv->child_breakpoint_bin, GTK_OVERFLOW_VISIBLE);
   adw_breakpoint_bin_set_warning_widget (ADW_BREAKPOINT_BIN (priv->child_breakpoint_bin),
@@ -1312,6 +1315,10 @@ adw_dialog_init (AdwDialog *self)
   g_object_bind_property (self, "height-request",
                           priv->child_breakpoint_bin, "height-request",
                           G_BINDING_DEFAULT);
+  g_signal_connect_swapped (priv->child_breakpoint_bin,
+                            "notify::current-breakpoint",
+                            G_CALLBACK (child_breakpoint_bin_notify_current_breakpoint_cb),
+                            self);
 }
 
 static void
@@ -1320,13 +1327,15 @@ adw_dialog_buildable_add_child (GtkBuildable *buildable,
                                 GObject      *child,
                                 const char   *type)
 {
-  if (GTK_IS_WIDGET (child))
+  if (GTK_IS_WIDGET (child)) {
+    gtk_buildable_child_deprecation_warning (buildable, builder, NULL, "child");
     adw_dialog_set_child (ADW_DIALOG (buildable), GTK_WIDGET (child));
-  else if (ADW_IS_BREAKPOINT (child))
+  } else if (ADW_IS_BREAKPOINT (child)) {
     adw_dialog_add_breakpoint (ADW_DIALOG (buildable),
                                g_object_ref (ADW_BREAKPOINT (child)));
-  else
+  } else {
     parent_buildable_iface->add_child (buildable, builder, child, type);
+  }
 }
 
 static void
@@ -1337,6 +1346,11 @@ adw_dialog_buildable_init (GtkBuildableIface *iface)
   iface->add_child = adw_dialog_buildable_add_child;
 }
 
+static void
+adw_dialog_shortcut_manager_init (GtkShortcutManagerInterface *iface)
+{
+}
+
 /**
  * adw_dialog_new:
  *
@@ -1445,6 +1459,7 @@ adw_dialog_set_title (AdwDialog  *self,
   AdwDialogPrivate *priv;
 
   g_return_if_fail (ADW_IS_DIALOG (self));
+  g_return_if_fail (title != NULL);
 
   priv = adw_dialog_get_instance_private (self);
 
@@ -1708,13 +1723,13 @@ adw_dialog_get_presentation_mode (AdwDialog *self)
  *
  * Sets presentation mode for @self.
  *
- * When set to `ADW_DIALOG_AUTO`, the dialog appears as a bottom sheet when the
- * following condition is met: `max-width: 450px or max-height: 360px`, and as a
- * floating window otherwise.
+ * When set to [enum@Adw.DialogPresentationMode.auto], the dialog appears as a
+ * bottom sheet when the following condition is met:
+ * `max-width: 450px or max-height: 360px`, and as a floating window otherwise.
  *
- * Set it to `ADW_DIALOG_FLOATING` or `ADW_DIALOG_BOTTOM_SHEET` to always
- * present it a floating window or a bottom sheet respectively, regardless of
- * available size.
+ * Set it to [enum@Adw.DialogPresentationMode.floating] or
+ * [enum@Adw.DialogPresentationMode.bottom-sheet] to always present it a
+ * floating window or a bottom sheet respectively, regardless of available size.
  *
  * Presentation mode does nothing for dialogs presented as a window.
  *
@@ -1800,7 +1815,7 @@ adw_dialog_set_focus (AdwDialog *self,
   if (priv->focus_widget == focus)
     return;
 
-  if (!gtk_widget_get_can_focus (priv->bin)) {
+  if (!priv->bin || !gtk_widget_get_can_focus (priv->bin)) {
     g_set_weak_pointer (&priv->last_focus, priv->focus_widget);
     set_focus (self, focus);
     return;
@@ -1934,6 +1949,9 @@ adw_dialog_close (AdwDialog *self)
     GtkWidget *window = priv->window;
     priv->window = NULL;
 
+    gtk_widget_remove_controller (GTK_WIDGET (self), priv->window_close_controller);
+    priv->window_close_controller = NULL;
+
     if (priv->closing_callback)
       priv->closing_callback (self, priv->user_data);
 
