@@ -13,6 +13,7 @@
 #include "adw-animation-util.h"
 #include "adw-bin.h"
 #include "adw-gizmo-private.h"
+#include "adw-gtkbuilder-utils-private.h"
 #include "adw-length-unit.h"
 #include "adw-shadow-helper-private.h"
 #include "adw-spring-animation.h"
@@ -63,8 +64,6 @@
  *
  * ```xml
  * <object class="AdwWindow">
- *   <property name="width-request">360</property>
- *   <property name="height-request">200</property>
  *   <property name="default-width">800</property>
  *   <property name="default-height">800</property>
  *   <child>
@@ -155,7 +154,7 @@
  *
  * ## Accessibility
  *
- * `AdwOverlaySplitView` uses the `GTK_ACCESSIBLE_ROLE_GROUP` role.
+ * `AdwOverlaySplitView` uses the [enum@Gtk.AccessibleRole.group] role.
  *
  * Since: 1.4
  */
@@ -192,6 +191,9 @@ struct _AdwOverlaySplitView
   AdwLengthUnit sidebar_width_unit;
 
   int sidebar_width;
+
+  GtkWidget *last_sidebar_focus;
+  GtkWidget *last_content_focus;
 };
 
 static void adw_overlay_split_view_buildable_init (GtkBuildableIface *iface);
@@ -247,8 +249,8 @@ update_swipe_tracker (AdwOverlaySplitView *self)
 static void
 update_shield (AdwOverlaySplitView *self)
 {
-  gtk_widget_set_visible (self->shield,
-                          self->collapsed && self->show_progress > 0);
+  gtk_widget_set_child_visible (self->shield,
+                                self->collapsed && self->show_progress > 0);
 
   gtk_widget_queue_allocate (GTK_WIDGET (self));
 }
@@ -295,6 +297,11 @@ set_show_sidebar (AdwOverlaySplitView *self,
                   gboolean             animate,
                   double               velocity)
 {
+  GtkRoot *root;
+  GtkWidget *focus;
+  gboolean focus_in_sidebar = FALSE;
+  gboolean focus_in_content = FALSE;
+
   show_sidebar = !!show_sidebar;
 
   if (self->show_sidebar == show_sidebar)
@@ -302,11 +309,51 @@ set_show_sidebar (AdwOverlaySplitView *self,
 
   self->show_sidebar = show_sidebar;
 
+  root = gtk_widget_get_root (GTK_WIDGET (self));
+  if (root)
+    focus = gtk_root_get_focus (root);
+  else
+    focus = NULL;
+
+  if (focus) {
+    if (!show_sidebar && gtk_widget_is_ancestor (focus, self->sidebar_bin)) {
+      focus_in_sidebar = TRUE;
+      g_set_weak_pointer (&self->last_sidebar_focus, focus);
+    }
+
+    if (show_sidebar && self->collapsed && gtk_widget_is_ancestor (focus, self->content_bin)) {
+      focus_in_content = TRUE;
+      g_set_weak_pointer (&self->last_content_focus, focus);
+    }
+  }
+
+  gtk_widget_set_can_focus (self->sidebar_bin, !self->collapsed || show_sidebar);
+  gtk_widget_set_can_focus (self->content_bin, !self->collapsed || !show_sidebar);
+
+  if (show_sidebar) {
+    gtk_widget_set_child_visible (self->sidebar_bin, TRUE);
+
+    if (self->collapsed && focus_in_content) {
+      if (self->last_sidebar_focus)
+        gtk_widget_grab_focus (self->last_sidebar_focus);
+      else
+        gtk_widget_child_focus (self->sidebar_bin, GTK_DIR_TAB_FORWARD);
+    }
+  } else if (focus_in_sidebar) {
+    if (self->last_content_focus)
+      gtk_widget_grab_focus (self->last_content_focus);
+    else
+      gtk_widget_child_focus (self->content_bin, GTK_DIR_TAB_FORWARD);
+  }
+
   if (animate) {
     if (!self->swipe_active)
       animate_sidebar (self, show_sidebar ? 1 : 0, velocity);
   } else {
     set_show_progress (show_sidebar ? 1 : 0, self);
+
+    if (!show_sidebar)
+      gtk_widget_set_child_visible (self->sidebar_bin, FALSE);
   }
 
   g_object_notify_by_pspec (G_OBJECT (self), props[PROP_SHOW_SIDEBAR]);
@@ -347,6 +394,7 @@ begin_swipe_cb (AdwSwipeTracker     *tracker,
     return;
 
   adw_animation_pause (self->animation);
+  gtk_widget_set_child_visible (self->sidebar_bin, TRUE);
 
   self->swipe_detected = FALSE;
   self->swipe_active = TRUE;
@@ -390,15 +438,6 @@ released_cb (GtkGestureClick     *gesture,
   adw_overlay_split_view_set_show_sidebar (self, FALSE);
 }
 
-static inline void
-get_preferred_size (GtkWidget      *widget,
-                    GtkOrientation  orientation,
-                    int            *min,
-                    int            *nat)
-{
-  gtk_widget_measure (widget, orientation, -1, min, nat, NULL, NULL);
-}
-
 static int
 get_sidebar_width (AdwOverlaySplitView *self,
                    int                  width,
@@ -700,6 +739,13 @@ update_collapsed (AdwOverlaySplitView *self)
   }
 }
 
+static void
+animation_done_cb (AdwOverlaySplitView *self)
+{
+  if (self->show_progress < 0.5)
+    gtk_widget_set_child_visible (self->sidebar_bin, FALSE);
+}
+
 static void
 adw_overlay_split_view_snapshot (GtkWidget   *widget,
                                  GtkSnapshot *snapshot)
@@ -831,6 +877,9 @@ adw_overlay_split_view_dispose (GObject *object)
 {
   AdwOverlaySplitView *self = ADW_OVERLAY_SPLIT_VIEW (object);
 
+  g_clear_weak_pointer (&self->last_sidebar_focus);
+  g_clear_weak_pointer (&self->last_content_focus);
+
   g_clear_pointer (&self->sidebar_bin, gtk_widget_unparent);
   g_clear_pointer (&self->content_bin, gtk_widget_unparent);
 
@@ -860,7 +909,7 @@ adw_overlay_split_view_class_init (AdwOverlaySplitViewClass *klass)
   widget_class->compute_expand = adw_widget_compute_expand;
 
   /**
-   * AdwOverlaySplitView:content: (attributes org.gtk.Property.get=adw_overlay_split_view_get_content org.gtk.Property.set=adw_overlay_split_view_set_content)
+   * AdwOverlaySplitView:content:
    *
    * The content widget.
    *
@@ -872,7 +921,7 @@ adw_overlay_split_view_class_init (AdwOverlaySplitViewClass *klass)
                          G_PARAM_READWRITE | G_PARAM_STATIC_STRINGS | G_PARAM_EXPLICIT_NOTIFY);
 
   /**
-   * AdwOverlaySplitView:sidebar: (attributes org.gtk.Property.get=adw_overlay_split_view_get_sidebar org.gtk.Property.set=adw_overlay_split_view_set_sidebar)
+   * AdwOverlaySplitView:sidebar:
    *
    * The sidebar widget.
    *
@@ -884,7 +933,7 @@ adw_overlay_split_view_class_init (AdwOverlaySplitViewClass *klass)
                          G_PARAM_READWRITE | G_PARAM_STATIC_STRINGS | G_PARAM_EXPLICIT_NOTIFY);
 
   /**
-   * AdwOverlaySplitView:collapsed: (attributes org.gtk.Property.get=adw_overlay_split_view_get_collapsed org.gtk.Property.set=adw_overlay_split_view_set_collapsed)
+   * AdwOverlaySplitView:collapsed:
    *
    * Whether the split view is collapsed.
    *
@@ -899,12 +948,12 @@ adw_overlay_split_view_class_init (AdwOverlaySplitViewClass *klass)
                           G_PARAM_READWRITE | G_PARAM_STATIC_STRINGS | G_PARAM_EXPLICIT_NOTIFY);
 
   /**
-   * AdwOverlaySplitView:sidebar-position: (attributes org.gtk.Property.get=adw_overlay_split_view_get_sidebar_position org.gtk.Property.set=adw_overlay_split_view_set_sidebar_position)
+   * AdwOverlaySplitView:sidebar-position:
    *
    * The sidebar position.
    *
-   * If it's set to `GTK_PACK_START`, the sidebar is displayed before the content,
-   * if `GTK_PACK_END`, it's displayed after the content.
+   * If it's set to [enum@Gtk.PackType.start], the sidebar is displayed before
+   * the content; if [enum@Gtk.PackType.end], it's displayed after the content.
    *
    * Since: 1.4
    */
@@ -915,7 +964,7 @@ adw_overlay_split_view_class_init (AdwOverlaySplitViewClass *klass)
                        G_PARAM_READWRITE | G_PARAM_STATIC_STRINGS | G_PARAM_EXPLICIT_NOTIFY);
 
   /**
-   * AdwOverlaySplitView:show-sidebar: (attributes org.gtk.Property.get=adw_overlay_split_view_get_show_sidebar org.gtk.Property.set=adw_overlay_split_view_set_show_sidebar)
+   * AdwOverlaySplitView:show-sidebar:
    *
    * Whether the sidebar widget is shown.
    *
@@ -927,7 +976,7 @@ adw_overlay_split_view_class_init (AdwOverlaySplitViewClass *klass)
                           G_PARAM_READWRITE | G_PARAM_STATIC_STRINGS | G_PARAM_EXPLICIT_NOTIFY);
 
   /**
-   * AdwOverlaySplitView:pin-sidebar: (attributes org.gtk.Property.get=adw_overlay_split_view_get_pin_sidebar org.gtk.Property.set=adw_overlay_split_view_set_pin_sidebar)
+   * AdwOverlaySplitView:pin-sidebar:
    *
    * Whether the sidebar widget is pinned.
    *
@@ -943,7 +992,7 @@ adw_overlay_split_view_class_init (AdwOverlaySplitViewClass *klass)
                           G_PARAM_READWRITE | G_PARAM_STATIC_STRINGS | G_PARAM_EXPLICIT_NOTIFY);
 
   /**
-   * AdwOverlaySplitView:enable-show-gesture: (attributes org.gtk.Property.get=adw_overlay_split_view_get_enable_show_gesture org.gtk.Property.set=adw_overlay_split_view_set_enable_show_gesture)
+   * AdwOverlaySplitView:enable-show-gesture:
    *
    * Whether the sidebar can be opened with an edge swipe gesture.
    *
@@ -957,7 +1006,7 @@ adw_overlay_split_view_class_init (AdwOverlaySplitViewClass *klass)
                           G_PARAM_READWRITE | G_PARAM_STATIC_STRINGS | G_PARAM_EXPLICIT_NOTIFY);
 
   /**
-   * AdwOverlaySplitView:enable-hide-gesture: (attributes org.gtk.Property.get=adw_overlay_split_view_get_enable_hide_gesture org.gtk.Property.set=adw_overlay_split_view_set_enable_hide_gesture)
+   * AdwOverlaySplitView:enable-hide-gesture:
    *
    * Whether the sidebar can be closed with a swipe gesture.
    *
@@ -971,7 +1020,7 @@ adw_overlay_split_view_class_init (AdwOverlaySplitViewClass *klass)
                           G_PARAM_READWRITE | G_PARAM_STATIC_STRINGS | G_PARAM_EXPLICIT_NOTIFY);
 
   /**
-   * AdwOverlaySplitView:min-sidebar-width: (attributes org.gtk.Property.get=adw_overlay_split_view_get_min_sidebar_width org.gtk.Property.set=adw_overlay_split_view_set_min_sidebar_width)
+   * AdwOverlaySplitView:min-sidebar-width:
    *
    * The minimum sidebar width.
    *
@@ -989,7 +1038,7 @@ adw_overlay_split_view_class_init (AdwOverlaySplitViewClass *klass)
                          G_PARAM_READWRITE | G_PARAM_STATIC_STRINGS | G_PARAM_EXPLICIT_NOTIFY);
 
   /**
-   * AdwOverlaySplitView:max-sidebar-width: (attributes org.gtk.Property.get=adw_overlay_split_view_get_max_sidebar_width org.gtk.Property.set=adw_overlay_split_view_set_max_sidebar_width)
+   * AdwOverlaySplitView:max-sidebar-width:
    *
    * The maximum sidebar width.
    *
@@ -1007,7 +1056,7 @@ adw_overlay_split_view_class_init (AdwOverlaySplitViewClass *klass)
                          G_PARAM_READWRITE | G_PARAM_STATIC_STRINGS | G_PARAM_EXPLICIT_NOTIFY);
 
   /**
-   * AdwOverlaySplitView:sidebar-width-fraction: (attributes org.gtk.Property.get=adw_overlay_split_view_get_sidebar_width_fraction org.gtk.Property.set=adw_overlay_split_view_set_sidebar_width_fraction)
+   * AdwOverlaySplitView:sidebar-width-fraction:
    *
    * The preferred sidebar width as a fraction of the total width.
    *
@@ -1026,7 +1075,7 @@ adw_overlay_split_view_class_init (AdwOverlaySplitViewClass *klass)
                          G_PARAM_READWRITE | G_PARAM_STATIC_STRINGS | G_PARAM_EXPLICIT_NOTIFY);
 
   /**
-   * AdwOverlaySplitView:sidebar-width-unit: (attributes org.gtk.Property.get=adw_overlay_split_view_get_sidebar_width_unit org.gtk.Property.set=adw_overlay_split_view_set_sidebar_width_unit)
+   * AdwOverlaySplitView:sidebar-width-unit:
    *
    * The length unit for minimum and maximum sidebar widths.
    *
@@ -1115,6 +1164,9 @@ adw_overlay_split_view_init (AdwOverlaySplitView *self)
     adw_spring_animation_new (GTK_WIDGET (self), 0, 0,
                              adw_spring_params_new (1, 0.5, 500), target);
 
+  g_signal_connect_swapped (self->animation, "done",
+                            G_CALLBACK (animation_done_cb), self);
+
   update_shield (self);
   update_collapsed (self);
   update_swipe_tracker (self);
@@ -1126,17 +1178,21 @@ adw_overlay_split_view_add_child (GtkBuildable *buildable,
                                   GObject      *child,
                                   const char   *type)
 {
-  if (!g_strcmp0 (type, "content"))
+  if (!g_strcmp0 (type, "content")) {
+    gtk_buildable_child_deprecation_warning (buildable, builder, "content", "content");
     adw_overlay_split_view_set_content (ADW_OVERLAY_SPLIT_VIEW (buildable),
                                         GTK_WIDGET (child));
-  else if (!g_strcmp0 (type, "sidebar"))
+  } else if (!g_strcmp0 (type, "sidebar")) {
+    gtk_buildable_child_deprecation_warning (buildable, builder, "sidebar", "sidebar");
     adw_overlay_split_view_set_sidebar (ADW_OVERLAY_SPLIT_VIEW (buildable),
                                         GTK_WIDGET (child));
-  else if (!type && GTK_IS_WIDGET (child))
+  } else if (!type && GTK_IS_WIDGET (child)) {
+    gtk_buildable_child_deprecation_warning (buildable, builder, NULL, "content");
     adw_overlay_split_view_set_content (ADW_OVERLAY_SPLIT_VIEW (buildable),
                                         GTK_WIDGET (child));
-  else
+  } else {
     parent_buildable_iface->add_child (buildable, builder, child, type);
+  }
 }
 
 static void
@@ -1164,9 +1220,6 @@ adw_overlay_split_view_get_snap_points (AdwSwipeable *swipeable,
   gboolean can_close = self->show_progress < 1 || self->enable_hide_gesture || self->swipe_active;
   double *points;
 
-  if (!can_open && !can_close)
-    return NULL;
-
   if (can_open && can_close) {
     points = g_new0 (double, 2);
 
@@ -1262,7 +1315,7 @@ adw_overlay_split_view_new (void)
 }
 
 /**
- * adw_overlay_split_view_get_sidebar: (attributes org.gtk.Method.get_property=sidebar)
+ * adw_overlay_split_view_get_sidebar:
  * @self: an overlay split view
  *
  * Gets the sidebar widget for @self.
@@ -1280,7 +1333,7 @@ adw_overlay_split_view_get_sidebar (AdwOverlaySplitView *self)
 }
 
 /**
- * adw_overlay_split_view_set_sidebar: (attributes org.gtk.Method.set_property=sidebar)
+ * adw_overlay_split_view_set_sidebar:
  * @self: an overlay split view
  * @sidebar: (nullable): the sidebar widget
  *
@@ -1295,12 +1348,12 @@ adw_overlay_split_view_set_sidebar (AdwOverlaySplitView *self,
   g_return_if_fail (ADW_IS_OVERLAY_SPLIT_VIEW (self));
   g_return_if_fail (sidebar == NULL || GTK_IS_WIDGET (sidebar));
 
-  if (sidebar)
-    g_return_if_fail (gtk_widget_get_parent (sidebar) == NULL);
-
   if (sidebar == adw_overlay_split_view_get_sidebar (self))
     return;
 
+  if (sidebar)
+    g_return_if_fail (gtk_widget_get_parent (sidebar) == NULL);
+
   adw_bin_set_child (ADW_BIN (self->sidebar_bin), sidebar);
 
   update_swipe_tracker (self);
@@ -1309,7 +1362,7 @@ adw_overlay_split_view_set_sidebar (AdwOverlaySplitView *self,
 }
 
 /**
- * adw_overlay_split_view_get_content: (attributes org.gtk.Method.get_property=content)
+ * adw_overlay_split_view_get_content:
  * @self: an overlay split view
  *
  * Gets the content widget for @self.
@@ -1327,7 +1380,7 @@ adw_overlay_split_view_get_content (AdwOverlaySplitView *self)
 }
 
 /**
- * adw_overlay_split_view_set_content: (attributes org.gtk.Method.set_property=content)
+ * adw_overlay_split_view_set_content:
  * @self: an overlay split view
  * @content: (nullable): the content widget
  *
@@ -1342,19 +1395,19 @@ adw_overlay_split_view_set_content (AdwOverlaySplitView *self,
   g_return_if_fail (ADW_IS_OVERLAY_SPLIT_VIEW (self));
   g_return_if_fail (content == NULL || GTK_IS_WIDGET (content));
 
-  if (content)
-    g_return_if_fail (gtk_widget_get_parent (content) == NULL);
-
   if (content == adw_overlay_split_view_get_content (self))
     return;
 
+  if (content)
+    g_return_if_fail (gtk_widget_get_parent (content) == NULL);
+
   adw_bin_set_child (ADW_BIN (self->content_bin), content);
 
   g_object_notify_by_pspec (G_OBJECT (self), props[PROP_CONTENT]);
 }
 
 /**
- * adw_overlay_split_view_get_collapsed: (attributes org.gtk.Method.get_property=collapsed)
+ * adw_overlay_split_view_get_collapsed:
  * @self: an overlay split view
  *
  * Gets whether @self is collapsed.
@@ -1372,7 +1425,7 @@ adw_overlay_split_view_get_collapsed (AdwOverlaySplitView *self)
 }
 
 /**
- * adw_overlay_split_view_set_collapsed: (attributes org.gtk.Method.set_property=collapsed)
+ * adw_overlay_split_view_set_collapsed:
  * @self: an overlay split view
  * @collapsed: whether @self is collapsed
  *
@@ -1404,6 +1457,9 @@ adw_overlay_split_view_set_collapsed (AdwOverlaySplitView *self,
   if (!self->pin_sidebar)
     set_show_sidebar (self, !self->collapsed, FALSE, 0);
 
+  gtk_widget_set_can_focus (self->sidebar_bin, !collapsed || self->show_sidebar);
+  gtk_widget_set_can_focus (self->content_bin, !collapsed || !self->show_sidebar);
+
   update_collapsed (self);
 
   gtk_widget_queue_resize (GTK_WIDGET (self));
@@ -1428,7 +1484,7 @@ adw_overlay_split_view_set_collapsed (AdwOverlaySplitView *self,
 }
 
 /**
- * adw_overlay_split_view_get_sidebar_position: (attributes org.gtk.Method.get_property=sidebar-position)
+ * adw_overlay_split_view_get_sidebar_position:
  * @self: an overlay split view
  *
  * Gets the sidebar position for @self.
@@ -1446,14 +1502,14 @@ adw_overlay_split_view_get_sidebar_position (AdwOverlaySplitView *self)
 }
 
 /**
- * adw_overlay_split_view_set_sidebar_position: (attributes org.gtk.Method.set_property=sidebar-position)
+ * adw_overlay_split_view_set_sidebar_position:
  * @self: an overlay split view
  * @position: the new position
  *
  * Sets the sidebar position for @self.
  *
- * If it's set to `GTK_PACK_START`, the sidebar is displayed before the content,
- * if `GTK_PACK_END`, it's displayed after the content.
+ * If it's set to [enum@Gtk.PackType.start], the sidebar is displayed before the
+ * content; if [enum@Gtk.PackType.end], it's displayed after the content.
  *
  * Since: 1.4
  */
@@ -1483,7 +1539,7 @@ adw_overlay_split_view_set_sidebar_position (AdwOverlaySplitView *self,
 }
 
 /**
- * adw_overlay_split_view_get_show_sidebar: (attributes org.gtk.Method.get_property=show-sidebar)
+ * adw_overlay_split_view_get_show_sidebar:
  * @self: an overlay split view
  *
  * Gets whether the sidebar widget is shown for @self.
@@ -1501,7 +1557,7 @@ adw_overlay_split_view_get_show_sidebar (AdwOverlaySplitView *self)
 }
 
 /**
- * adw_overlay_split_view_set_show_sidebar: (attributes org.gtk.Method.set_property=show-sidebar)
+ * adw_overlay_split_view_set_show_sidebar:
  * @self: an overlay split view
  * @show_sidebar: whether to show the sidebar widget
  *
@@ -1519,7 +1575,7 @@ adw_overlay_split_view_set_show_sidebar (AdwOverlaySplitView *self,
 }
 
 /**
- * adw_overlay_split_view_get_pin_sidebar: (attributes org.gtk.Method.get_property=pin-sidebar)
+ * adw_overlay_split_view_get_pin_sidebar:
  * @self: an overlay split view
  *
  * Gets whether the sidebar widget is pinned for @self.
@@ -1537,7 +1593,7 @@ adw_overlay_split_view_get_pin_sidebar (AdwOverlaySplitView *self)
 }
 
 /**
- * adw_overlay_split_view_set_pin_sidebar: (attributes org.gtk.Method.set_property=pin-sidebar)
+ * adw_overlay_split_view_set_pin_sidebar:
  * @self: an overlay split view
  * @pin_sidebar: whether to pin the sidebar widget
  *
@@ -1566,7 +1622,7 @@ adw_overlay_split_view_set_pin_sidebar (AdwOverlaySplitView *self,
 }
 
 /**
- * adw_overlay_split_view_get_enable_show_gesture: (attributes org.gtk.Method.get_property=enable-show-gesture)
+ * adw_overlay_split_view_get_enable_show_gesture:
  * @self: an overlay split view
  *
  * Gets whether @self can be opened with an edge swipe gesture.
@@ -1584,7 +1640,7 @@ adw_overlay_split_view_get_enable_show_gesture (AdwOverlaySplitView *self)
 }
 
 /**
- * adw_overlay_split_view_set_enable_show_gesture: (attributes org.gtk.Method.set_property=enable-show-gesture)
+ * adw_overlay_split_view_set_enable_show_gesture:
  * @self: an overlay split view
  * @enable_show_gesture: whether @self can be opened with a swipe gesture
  *
@@ -1613,7 +1669,7 @@ adw_overlay_split_view_set_enable_show_gesture (AdwOverlaySplitView *self,
 }
 
 /**
- * adw_overlay_split_view_get_enable_hide_gesture: (attributes org.gtk.Method.get_property=enable-hide-gesture)
+ * adw_overlay_split_view_get_enable_hide_gesture:
  * @self: an overlay split view
  *
  * Gets whether @self can be closed with a swipe gesture.
@@ -1631,7 +1687,7 @@ adw_overlay_split_view_get_enable_hide_gesture (AdwOverlaySplitView *self)
 }
 
 /**
- * adw_overlay_split_view_set_enable_hide_gesture: (attributes org.gtk.Method.set_property=enable-hide-gesture)
+ * adw_overlay_split_view_set_enable_hide_gesture:
  * @self: an overlay split view
  * @enable_hide_gesture: whether @self can be closed with a swipe gesture
  *
@@ -1660,7 +1716,7 @@ adw_overlay_split_view_set_enable_hide_gesture (AdwOverlaySplitView *self,
 }
 
 /**
- * adw_overlay_split_view_get_min_sidebar_width: (attributes org.gtk.Method.get_property=min-sidebar-width)
+ * adw_overlay_split_view_get_min_sidebar_width:
  * @self: an overlay split view
  *
  * Gets the minimum sidebar width for @self.
@@ -1678,7 +1734,7 @@ adw_overlay_split_view_get_min_sidebar_width (AdwOverlaySplitView *self)
 }
 
 /**
- * adw_overlay_split_view_set_min_sidebar_width: (attributes org.gtk.Method.set_property=min-sidebar-width)
+ * adw_overlay_split_view_set_min_sidebar_width:
  * @self: an overlay split view
  * @width: the minimum width
  *
@@ -1708,7 +1764,7 @@ adw_overlay_split_view_set_min_sidebar_width (AdwOverlaySplitView *self,
 }
 
 /**
- * adw_overlay_split_view_get_max_sidebar_width: (attributes org.gtk.Method.get_property=max-sidebar-width)
+ * adw_overlay_split_view_get_max_sidebar_width:
  * @self: an overlay split view
  *
  * Gets the maximum sidebar width for @self.
@@ -1726,7 +1782,7 @@ adw_overlay_split_view_get_max_sidebar_width (AdwOverlaySplitView *self)
 }
 
 /**
- * adw_overlay_split_view_set_max_sidebar_width: (attributes org.gtk.Method.set_property=max-sidebar-width)
+ * adw_overlay_split_view_set_max_sidebar_width:
  * @self: an overlay split view
  * @width: the maximum width
  *
@@ -1756,7 +1812,7 @@ adw_overlay_split_view_set_max_sidebar_width (AdwOverlaySplitView *self,
 }
 
 /**
- * adw_overlay_split_view_get_sidebar_width_fraction: (attributes org.gtk.Method.get_property=sidebar-width-fraction)
+ * adw_overlay_split_view_get_sidebar_width_fraction:
  * @self: an overlay split view
  *
  * Gets the preferred sidebar width fraction for @self.
@@ -1774,7 +1830,7 @@ adw_overlay_split_view_get_sidebar_width_fraction (AdwOverlaySplitView *self)
 }
 
 /**
- * adw_overlay_split_view_set_sidebar_width_fraction: (attributes org.gtk.Method.set_property=sidebar-width-fraction)
+ * adw_overlay_split_view_set_sidebar_width_fraction:
  * @self: an overlay split view
  * @fraction: the preferred width fraction
  *
@@ -1807,7 +1863,7 @@ adw_overlay_split_view_set_sidebar_width_fraction (AdwOverlaySplitView *self,
 }
 
 /**
- * adw_overlay_split_view_get_sidebar_width_unit: (attributes org.gtk.Method.get_property=sidebar-width-unit)
+ * adw_overlay_split_view_get_sidebar_width_unit:
  * @self: an overlay split view
  *
  * Gets the length unit for minimum and maximum sidebar widths.
@@ -1825,7 +1881,7 @@ adw_overlay_split_view_get_sidebar_width_unit (AdwOverlaySplitView *self)
 }
 
 /**
- * adw_overlay_split_view_set_sidebar_width_unit: (attributes org.gtk.Method.set_property=sidebar-width-unit)
+ * adw_overlay_split_view_set_sidebar_width_unit:
  * @self: an overlay split view
  * @unit: the length unit
  *
