@@ -69,10 +69,9 @@ typedef struct
 
   gboolean search_enabled;
 
-  GtkFilter *filter;
+  GtkFilter *row_filter;
+  GtkFilter *page_filter;
   GtkFilterListModel *filter_model;
-
-  int n_pages;
 } AdwPreferencesDialogPrivate;
 
 static void adw_preferences_dialog_buildable_init (GtkBuildableIface *iface);
@@ -310,10 +309,11 @@ update_view_switcher (AdwPreferencesDialog *self)
   AdwPreferencesDialogPrivate *priv = adw_preferences_dialog_get_instance_private (self);
   AdwBreakpoint *breakpoint;
   AdwBreakpointCondition *main_condition, *fallback_condition, *condition;
+  int n_pages = get_n_pages (self);
 
   main_condition =
     adw_breakpoint_condition_new_length (ADW_BREAKPOINT_CONDITION_MAX_WIDTH,
-                                         VIEW_SWITCHER_PAGE_THRESHOLD * MAX (1, priv->n_pages),
+                                         VIEW_SWITCHER_PAGE_THRESHOLD * MAX (1, n_pages),
                                          ADW_LENGTH_UNIT_PT);
   fallback_condition =
     adw_breakpoint_condition_new_length (ADW_BREAKPOINT_CONDITION_MAX_WIDTH,
@@ -326,12 +326,14 @@ update_view_switcher (AdwPreferencesDialog *self)
 
   breakpoint = adw_breakpoint_bin_get_current_breakpoint (ADW_BREAKPOINT_BIN (priv->breakpoint_bin));
 
-  if (!breakpoint && priv->n_pages > 1)
+  if (!breakpoint && n_pages > 1)
     gtk_stack_set_visible_child (GTK_STACK (priv->view_switcher_stack), priv->view_switcher);
   else
     gtk_stack_set_visible_child (GTK_STACK (priv->view_switcher_stack), priv->title);
 
   adw_breakpoint_condition_free (condition);
+
+  gtk_filter_changed (priv->page_filter, GTK_FILTER_CHANGE_DIFFERENT);
 }
 
 static void
@@ -403,7 +405,7 @@ search_changed_cb (AdwPreferencesDialog *self)
   AdwPreferencesDialogPrivate *priv = adw_preferences_dialog_get_instance_private (self);
   guint n;
 
-  gtk_filter_changed (priv->filter, GTK_FILTER_CHANGE_DIFFERENT);
+  gtk_filter_changed (priv->row_filter, GTK_FILTER_CHANGE_DIFFERENT);
 
   n = g_list_model_get_n_items (G_LIST_MODEL (priv->filter_model));
 
@@ -418,6 +420,22 @@ stop_search_cb (AdwPreferencesDialog *self)
   gtk_toggle_button_set_active (priv->search_button, FALSE);
 }
 
+static void
+search_activated_cb (AdwPreferencesDialog *self)
+{
+  AdwPreferencesDialogPrivate *priv = adw_preferences_dialog_get_instance_private (self);
+  GtkListBoxRow *row;
+
+  if (!gtk_widget_get_mapped (GTK_WIDGET (priv->search_results)))
+    return;
+
+  row = gtk_list_box_get_row_at_index (priv->search_results, 0);
+  if (!row)
+    return;
+
+  gtk_widget_grab_focus (GTK_WIDGET (row));
+}
+
 static void
 adw_preferences_dialog_get_property (GObject    *object,
                                      guint       prop_id,
@@ -575,6 +593,8 @@ adw_preferences_dialog_class_init (AdwPreferencesDialogClass *klass)
   gtk_widget_class_bind_template_callback (widget_class, search_results_map);
   gtk_widget_class_bind_template_callback (widget_class, search_results_unmap);
   gtk_widget_class_bind_template_callback (widget_class, stop_search_cb);
+  gtk_widget_class_bind_template_callback (widget_class, search_activated_cb);
+  gtk_widget_class_bind_template_callback (widget_class, adw_widget_on_vertical_keynav_failed);
 }
 
 static GListModel *
@@ -598,17 +618,19 @@ adw_preferences_dialog_init (AdwPreferencesDialog *self)
 
   gtk_widget_init_template (GTK_WIDGET (self));
 
-  priv->filter = GTK_FILTER (gtk_custom_filter_new ((GtkCustomFilterFunc) filter_search_results, self, NULL));
-  expr = gtk_property_expression_new (GTK_TYPE_STACK_PAGE, NULL, "visible");
+  priv->row_filter = GTK_FILTER (gtk_custom_filter_new ((GtkCustomFilterFunc) filter_search_results, self, NULL));
+
+  expr = gtk_property_expression_new (ADW_TYPE_VIEW_STACK_PAGE, NULL, "visible");
+  priv->page_filter = GTK_FILTER (gtk_bool_filter_new (expr));
 
   model = G_LIST_MODEL (adw_view_stack_get_pages (priv->pages_stack));
-  model = G_LIST_MODEL (gtk_filter_list_model_new (model, GTK_FILTER (gtk_bool_filter_new (expr))));
+  model = G_LIST_MODEL (gtk_filter_list_model_new (model, priv->page_filter));
   model = G_LIST_MODEL (gtk_map_list_model_new (model,
                                                 (GtkMapListModelMapFunc) preferences_page_to_rows,
                                                 NULL,
                                                 NULL));
   model = G_LIST_MODEL (gtk_flatten_list_model_new (model));
-  priv->filter_model = gtk_filter_list_model_new (model, priv->filter);
+  priv->filter_model = gtk_filter_list_model_new (model, priv->row_filter);
 
   gtk_widget_set_visible (GTK_WIDGET (priv->search_button), FALSE);
 }
@@ -679,8 +701,10 @@ adw_preferences_dialog_add (AdwPreferencesDialog *self,
   g_object_bind_property (page, "title", stack_page, "title", G_BINDING_SYNC_CREATE);
   g_object_bind_property (page, "use-underline", stack_page, "use-underline", G_BINDING_SYNC_CREATE);
   g_object_bind_property (page, "name", stack_page, "name", G_BINDING_SYNC_CREATE);
+  g_object_bind_property (page, "visible", stack_page, "visible", G_BINDING_SYNC_CREATE);
+
+  g_signal_connect_swapped (stack_page, "notify::visible", G_CALLBACK (update_view_switcher), self);
 
-  priv->n_pages++;
   update_view_switcher (self);
 }
 
@@ -709,7 +733,6 @@ adw_preferences_dialog_remove (AdwPreferencesDialog *self,
   else
     ADW_CRITICAL_CANNOT_REMOVE_CHILD (self, page);
 
-  priv->n_pages--;
   update_view_switcher (self);
 }
 
